==> musicman-0.8.6.tar.gz: musicman/musicman/musicfolderinfo.cpp <==
/***************************************************************************
                          musicfolderinfo.cpp  -  description
                             -------------------
    begin                : Sat Jun 7 2003
    copyright            : (C) 2003 by Avi Alkalay
    email                : avi@unix.sh
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include <kfileitem.h>
#include <kio/global.h>
#include "musicfolderinfo.h"

MusicFolderInfo::MusicFolderInfo() {
	items=0;
	playingTime=0;
	size=0;
	subFolders=0;
}


/** Adds the file info to this folder statistics.*/
void MusicFolderInfo::add(const KFileItem &file) {
	KFileMetaInfo itemInfo;

	itemInfo=file.metaInfo();
	playingTime+=itemInfo.value("Length").toUInt();
	items++;
	size+=file.size();
}

/** Adds a subfolder statistics to this folder statistics.*/
void MusicFolderInfo::add(const MusicFolderInfo &folder) {
	subFolders++;
	items+=folder.items;
	playingTime+=folder.playingTime;
	size+=folder.size;
}



/** Returns the string for the playing time represented as hh:mm:ss */
QString MusicFolderInfo::nicePlayingTime() {
	ulong h=0,m=0,s=playingTime;
	QString formated;

	if (s >= 3600) {
		h=playingTime/3600;
		s=playingTime%3600;    // residual
	}

	if (s >= 60) {
		m=s/60;
		s=s%60;    // residual
	}

	if (s<10) formated=QString("0%1").arg(s);
	else formated=QString("%1").arg(s);

	if (m<10) formated.prepend(QString("0%1:").arg(m));
	else formated.prepend(QString("%1:").arg(m));

	if (h) {
		if (h<10) formated.prepend(QString("0%1:").arg(h));
		else formated.prepend(QString("%1:").arg(h));
	}

	return formated;
}

==> musicman-0.11.tar.gz: musicman/musicman/musicfolderinfo.cpp <==
/***************************************************************************
                          musicfolderinfo.cpp  -  description
                             -------------------
    begin                : Sat Jun 7 2003
    copyright            : (C) 2003 by Avi Alkalay
    email                : avi@unix.sh
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include <kfileitem.h>
#include <kio/global.h>
#include "musicfolderinfo.h"

MusicFolderInfo::MusicFolderInfo() {
	items=0;
	playingTime=0;
	size=0;
	subFolders=0;
}


/** Adds the file info to this folder statistics.*/
void MusicFolderInfo::add(const KFileItem &file) {
	KFileMetaInfo itemInfo;

	itemInfo=file.metaInfo();
	if (!itemInfo.isEmpty()) playingTime+=itemInfo.value("Length").toUInt();
	items++;
	size+=file.size();
}

/** Adds a subfolder statistics to this folder statistics.*/
void MusicFolderInfo::add(const MusicFolderInfo &folder) {
	subFolders++;
	items+=folder.items;
	playingTime+=folder.playingTime;
	size+=folder.size;
}



/** Returns the string for the playing time represented as hh:mm:ss */
QString MusicFolderInfo::nicePlayingTime() {
	ulong h=0,m=0,s=playingTime;
	QString formated;

	if (s >= 3600) {
		h=playingTime/3600;
		s=playingTime%3600;    // residual
	}

	if (s >= 60) {
		m=s/60;
		s=s%60;    // residual
	}

	if (s<10) formated=QString("0%1").arg(s);
	else formated=QString("%1").arg(s);

	if (m<10) formated.prepend(QString("0%1:").arg(m));
	else formated.prepend(QString("%1:").arg(m));

	if (h) {
		if (h<10) formated.prepend(QString("0%1:").arg(h));
		else formated.prepend(QString("%1:").arg(h));
	}

	return formated;
}
